@@ -1,5 +1,5 @@
 package App::rshasum;
-$App::rshasum::VERSION = '0.4.0';
+$App::rshasum::VERSION = '0.6.0';
 use strict;
 use warnings;
 
@@ -89,7 +89,7 @@ App::rshasum - recursive shasum.
 
 =head1 VERSION
 
-version 0.4.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -97,6 +97,33 @@ version 0.4.0
     rshasum --digest=SHA-256 --skip='\.sw[a-zA-Z]*\z' --skip='~\z'
     rshasum --digest=SHA-256 --start-path='/home/random-j-user'
 
+=head1 DESCRIPTION
+
+A recursive digest calculator that prints digests for all files
+in a directory tree, as well as a total, summary digest of the output.
+
+=head1 FLAGS
+
+=head2 --digest
+
+The digest algorithm to use. Required. E.g:
+
+    --digest=SHA-256
+    --digest=SHA-512
+    --digest=MD5
+
+=head2 --skip
+
+Perl 5 regexes which when matched against the relative path,
+skips and prunes them.
+
+Can be specified more than one time.
+
+=head2 --start-path
+
+The start path for the traversal. Defaults to "." (the
+current working directory).
+
 =head1 METHODS
 
 =head2 run
